@@ -354,7 +354,7 @@
 #define wxUSE_GRAPHICS_CONTEXT 1
 #endif
 
-#define wxUSE_CAIRO 0
+#define wxUSE_CAIRO 1
 
 
 
@@ -907,7 +907,7 @@
 
 
 /* define with the name of timezone variable */
-#define WX_TIMEZONE timezone
+#define WX_TIMEZONE __timezone
 
 /* The type of 3rd argument to getsockname() - usually size_t or int */
 #define WX_SOCKLEN_T socklen_t
